Skip to contents

settings for whole run with many paths per input -> settings for one ensemble member with one path per input

Usage

subset_paths(settings, path_nums)

Arguments

settings

single-site settings object (not Multisettings)

path_nums

named list of input indices (one row of the sample design)