Skip to contents

Each segment will run in its own subdirectory, starting from the restart file written at the end of the previous segment. Crop parameters can be altered by specifying a different PFT in the segment file.

Usage

write_segmented_configs.SIPNET(settings, input_design = NULL, ...)

Arguments

settings

a single PEcAn settings object (not MultiSettings)

input_design

data frame in the format returned by PEcAn.uncertainty::generate_joint_ensemble_design(), reporting which ensemble members to select for each input

...

further arguments passed on to write_segment_configs()

Author

Alexey Shiklomanov, Chris Black