Compute first and last indices to extract from a Sipnet clim file
Source:R/sipnet_time_range_idx.R
sipnet_time_range_idx.RdGiven vectors of integer years, integer days-of-year, and decimal hours, computes the first and last indices that fall between the given start and end times.
Usage
sipnet_time_range_idx(
yrs,
ydays,
hrs,
start_yr,
start_yday,
start_hr,
end_yr,
end_yday,
end_hr
)