Split SIPNET inputs into multiple files based on start and end time
Source:R/split_inputs.SIPNET.R
split_inputs.SIPNET.RdSubset each SIPNET input file and write a new file containing values >= start.time and < end.time (note: end time is not inclusive)
Arguments
- start.time
Start date or datetime for splitting
- stop.time
End date or datetime for splitting
- inputs
Named
inputslist as provided by PEcAnsettings. Must have structure like:list(met = list(path = "path/to/sipnet.clim"), events = list(path = "path/to/events.in"), ...)- overwrite
if
TRUE, overwrite existing target file (DefaultFALSE)- outpath
if specified, write output to a new directory. Default
NULLwrites back to the directory being read
Value
Modified inputs list with all path entries replaced with new
paths (suitable for inserting back into settings$run$inputs).