Extract subset of a sipnet clim file based on start and end time
Source:R/split_inputs.SIPNET.R
split_sipnet_met.RdExtract subset of a sipnet clim file based on start and end time
Arguments
- start.time
start date and time at which to start extraction
- stop.time
stop date and time at which to stop extraction
- met
path to sipnet clim file to be split
- overwrite
if
TRUE, overwrite existing target file (DefaultFALSE)- outpath
if specified, write output to a new directory. Default
NULLwrites back to the directory being read