settings for whole run with many paths per input -> settings for one ensemble member with one path per input
Source:R/write_segmented_configs.R
subset_paths.Rdsettings for whole run with many paths per input -> settings for one ensemble member with one path per input