Break a Sipnet simulation into time segments with possibly changed parameters
Source:R/write_segmented_configs.R
write_segmented_configs.SIPNET.RdEach segment will run in its own subdirectory, starting from the restart file written at the end of the previous segment. Crop parameters can be altered by specifying a different PFT in the segment file.
Arguments
- settings
a single PEcAn settings object (not MultiSettings)
- input_design
data frame in the format returned by
PEcAn.uncertainty::generate_joint_ensemble_design(), reporting which ensemble members to select for each input- ...
further arguments passed on to
write_segment_configs()